	program	coarsengrid

!-----------------------------------------------------------------------
!			    ,
!	AUTHOR:		Andre Fortunato - 2010-11-16
!
!	PURPOSE:	Coarsens a grid for visualization purposes
!			All nodes within distmin of another node are
!			eliminated
!
!-----------------------------------------------------------------------

	include		'coarsengrid.cmn'
	real*8		x(MXNOD),y(MXNOD),h(MXNOD)
	real*8		xp(MXNOD),yp(MXNOD),hp(MXNOD)
	real*8		dist2,distmin,distmin2,xi,yi
	integer*4	ncon(MXEL,3)
	integer*4	i,j,nodes,nel,np
	integer*4	iargc
	logical 	igood(MXNOD)
	character*40	file
!-----------------------------------------------------------------------
!  -  help
	if (iargc() .ne. 3) then
	    write(*,*)'Program coarsengrid'
	    write(*,*)'Purpose: Coarsen a grid for visualization purposes'
	    write(*,*)'         All nodes within distmin of another node'
	    write(*,*)'         are eliminated'
	    write(*,*)'format: coarsengrid grid distmin bpt'
	    stop
	endif

!  -  read from screen
	call getarg(1,file)
	call rgrid(file,nel,nodes,x,y,h,ncon)
	call getarg(2,file)
	read(file,*)distmin
	distmin2 = distmin*distmin
	call getarg(3,file)

!  -  eliminate points
	igood = .TRUE.
	do i = 1, nodes
	    xi   = x(i)
	    yi   = y(i)
	    if (igood(i)) then
		do j = i+1, nodes
		    if (igood(j)) then
			dist2 = (xi-x(j))*(xi-x(j))+(yi-y(j))*(yi-y(j))
			if (dist2 < distmin2) igood(j) = .FALSE.
		    endif
		end do
	    endif
	end do
	np = 0
	do i = 1, nodes
	    if (igood(i)) then
                np = np+1
		xp(np) = x(i)
		yp(np) = y(i)
		hp(np) = h(i)
	    endif
	end do

!  -  write build points file
	call wbpt(file,xp,yp,hp,np)

	end

!-----------------------------------------------------------------------
	subroutine	rgrid(file,nel,nodes,x,y,h,ncon)

!-----------------------------------------------------------------------
!			    ,
!	AUTHOR:		Andre Fortunato - 95-04-14
!
!	PURPOSE:	read grid file in .gr3 format
!
!-----------------------------------------------------------------------
	include		'coarsengrid.cmn'
	real*8		x(MXNOD),y(MXNOD),h(MXNOD)
	integer*4	ncon(MXEL,3)
	character*40	file,alpha

	integer*4	i,j,n,nodes,nel
!-----------------------------------------------------------------------

	open(unit=1,file=file,status='old')
        read(1,20)alpha
20	format(a40)
        read(1,*)nel,nodes
        if (nel .gt. MXEL) then
            write(*,*)'Number of elements is too large:', nel
            write(*,*)'Update MXEL in coarsengrid.cmn and recompile'
            stop
        elseif (nodes .gt. MXNOD) then
            write(*,*)'Number of nodes is too large:', nodes
            write(*,*)'Update MXNOD in coarsengrid.cmn and recompile'
            stop
        endif

        do i = 1, nodes
            read(1,*)n,x(i),y(i),h(i)
        end do
        do i = 1, nel
            read(1,*)n,n,(ncon(i,j),j=1,3)
        end do
        close(1)

	return
	end

!-----------------------------------------------------------------------
	subroutine	wbpt(file,x,y,h,n)

!-----------------------------------------------------------------------
!			    ,
!	AUTHOR:		Andre Fortunato - 98-03-17
!
!	PURPOSE:	write a build points file
!
!-----------------------------------------------------------------------

	include		'coarsengrid.cmn'
	real*8		x(MXNP),y(MXNP),h(MXNP)
	real*4		xs,ys,hs
	integer*4	i,j,n
	character*40	file
!-----------------------------------------------------------------------
	open(1,file=file,status='unknown')
	write(1,*)'Writen by program coarsengrid'
	write(1,*)n
	do i = 1, n
	    xs = x(i)
	    ys = y(i)
	    hs = h(i)
	    write(1,*)i,xs,ys,hs
	end do
	close(1)

	return
	end

!-----------------------------------------------------------------------
